@@ -32,10 +32,10 @@ from rpcdispatcher import RPCDispatcher, rpcmethod
 
 _MAJOR = 0
 _MINOR = 1
-_PATCH = 2
+_PATCH = 3
 
 __author__ = 'David Fischer'
-__author_email__ = 'rpc4django@gmail.com'
+__author_email__ = 'rpc4django@davidfischer.name'
 __modulename__ = 'rpc4django'
 __description__ = 'Handles JSONRPC and XMLRPC requests easily with Django'
 __url__ = 'http://www.davidfischer.name/rpc4django'
