@@ -87,17 +87,21 @@ class TestRPCDispatcher(unittest.TestCase):
         
     def test_jsonrpc_call(self):
         jsontxt = '{"params":[],"method":"system.listMethods","id":1}'
-        expresp = '{"result": ["system.describe", "system.listMethods", "system.methodHelp", "system.methodSignature"], "id": 1, "error": null}'
         resp = self.d.jsondispatch(jsontxt)
-        self.assertEqual(resp, expresp)
+        jsondict = json.loads(resp)
+        self.assertTrue(jsondict['error'] is None)
+        self.assertEqual(jsondict['id'], 1)
+        self.assertTrue(isinstance(jsondict['result'], list))
         
     def test_register_method(self):
         self.d.register_method(self.add)
         
         jsontxt = '{"params":[1,2],"method":"add","id":1}'
-        expresp = '{"result": 3, "id": 1, "error": null}'
         resp = self.d.jsondispatch(jsontxt)
-        self.assertEqual(resp, expresp)
+        jsondict = json.loads(resp)
+        self.assertTrue(jsondict['error'] is None)
+        self.assertEqual(jsondict['id'], 1)
+        self.assertEqual(jsondict['result'], 3)
         
         xml = '<?xml version="1.0"?><methodCall><methodName>add</methodName><params><param><value><int>1</int></value></param><param><value><int>5</int></value></param></params></methodCall>'
         expresp = "<?xml version='1.0'?><methodResponse><params><param><value><int>6</int></value></param></params></methodResponse>"
